@@ -1,3 +1,3 @@
-import RGBMatrixEmulator.graphics 
+from RGBMatrixEmulator.graphics import *
 from RGBMatrixEmulator.emulators.matrix import RGBMatrix
 from RGBMatrixEmulator.emulators.options import RGBMatrixOptions
\ No newline at end of file
